from typing import Any

class BaseError(Exception):
    reason: Any
    def __init__(self, reason) -> None: ...

class NotFoundError(BaseError): ...
class DataError(BaseError): ...
class ValidationError(BaseError): ...
